Module store

Module store 

Structs

MemoryStore
A non-persistent implementation of Store

Traits

AppendableStore
Extension to regular Stores, which use an index as a key
AsyncStore
The AsyncStore trait is a version of the Store that is asynchrounous
AsyncStoreRead
AsyncStoreWrite
Hashable
Trait indicating that an object can be hased with respect to the CT protocol
OrderedStore
OrderedStoreRead
Extension to regular Stores, which have ordered keys
SearchableStore
SearchableStoreRead
Extension to a OrderedStoreRead, that allows looking through the store to look for specific entries,
Store
The Store trait is a basic key-value store trait
StoreBase
StoreRead
StoreWrite