pub struct MemoryStore<K, V>(/* private fields */);Expand description
A non-persistent implementation of Store
This can be useful for testing, or in settings, in which the data should not be stored, for example when running as a command line tool in CI