AsyncAppendableStore

Trait AsyncAppendableStore 

pub trait AsyncAppendableStore: AsyncOrderedStoreRead {
    // Required method
    fn append(&self, value: Self::Value) -> impl Future<Output = Self::Key>;
}
Async version of AppendableStore

Required Methods

fn append(&self, value: Self::Value) -> impl Future<Output = Self::Key>

Insert a value into the store and return the index

Arguments:
  • value: the value itself
Returns:
  • the index of the new value. This is the key under which the value can later be retreived

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors