CertificateChain

Struct CertificateChain 

pub struct CertificateChain(/* private fields */);
A CertificateChain chain of trust

These chains are what gets presented by TLS. They consist of a number of X.509 Certificates, from the source to a root of trust.

Implementations

Source

impl CertificateChain

pub fn from_pem_chain(input: &str) -> Result<Self, CertificateError>

pub fn as_pem_chain(&self) -> String

pub fn from_der_chain(input: &[Vec<u8>]) -> Result<Self, CertificateError>

pub fn verify_chain(&self) -> Result<(), CertificateError>

pub fn verify_chain_against_root( &self, root: &Certificate, ) -> Result<(), CertificateError>

pub fn cert(&self) -> &Certificate

pub fn root(&self) -> &Certificate

pub fn as_leaf_v1( &self, sct: &SignedCertificateTimestamp, as_precert: bool, ) -> Result<MerkleTreeLeaf, CodecError>

Return the leaf of the SCT

Arguments

-sct: The v1::SignedCertificateTimestamp for which the leaf should be generated -as_precert: Whether the leaf should contain a precert entry or the certificate itself

Note:

If the SCT was obtained by extracting it out of the Certificate itself via Certificate::extract_scts_v1, then the corresponding leaf must be a precertificate and is_precert should be set to true.