TileId

Struct TileId 

pub struct TileId { /* private fields */ }

Implementations

Source

impl TileId

pub fn from_node_key(key: &NodeKey, tree_size: u64) -> Option<Self>

Returns the TileId of the tile, which contains the NodeKey.

The tree_height is used to calculate, wether the tile in question should be partial or not.

pub fn as_url(&self) -> String

Returns the Url path, at which this tile should be found

Append this path to the tile_url, to get the full path.

pub fn with_data(self, data: Arc<Vec<u8>>) -> Result<Tile, TilingError>

Create a Tile, by adding the data to this TileId

Returns:
  • None: If the length of the data is not a multiple if 32
  • Some(Tile) otherwise
pub fn is_partial(&self) -> bool

Returns true, if this TileId is partial, false otherwise

pub fn into_unpartial(self) -> Self

Turn a partial TileId into one that is not partial

Does nothing if TileId is already partial.