pub trait AppendableStore<K: Ord, V>: OrderedStoreRead<K, V> { // Required method fn append(&self, value: V) -> K; }
Extension to regular Stores, which use an index as a key
Stores
The main difference is, that the key is a u64 and the store determines the key when inserting
u64
Insert a value into the store and return the index
value