pub trait AsyncStore<K, V>: AsyncStoreRead<K, V> + AsyncStoreWrite<K, V> { }Expand description
The AsyncStore trait is a version of the Store that is asynchrounous
This allows the underlying store engine to make asynchronous requests, such as a distributed storage or rebuilding the store dynamically using tiles
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.